==> 507_3_1_1_newpda.zip: release/pages/replace_page.php <==
<?php

/**
 * Vltozk definilsa
 */ 
$szel=DOBOZSZELESSEG;
$mag=DOBOZMAGASSAG;
$lap=LAPMERET;
$szerviz=SZERVIZDIJ;
$szervizeng=SZERVIZDIJENG;
$kedv1=KEDV1;
$kedv1eng=KEDV1ENG;
$kedv2=KEDV2;
$kedv2eng=KEDV2ENG;
$kedv3=KEDV3;
$kedv3eng=KEDV3ENG;
$kedv4=KEDV4;
$kedv4eng=KEDV4ENG;
$autoszervizertek=AUTOSZERVIZERTEK;

 
$asztalFrom = $vars[1];
$jobID = $vars[2];
$asztalkod = $vars[3];

$station = 1;

$athelyez = (isset($_GET['athelyez'])) ? (int)$_GET['athelyez'] : 0;
$athelyez = ($athelyez==0) ? 1 : $athelyez;

$athelyezesStart = (isset($_GET['athelyezesStart'])) ? (int)$_GET['athelyezesStart'] : 0;
$athelyezesStart = ($athelyezesStart==0) ? 1 : $athelyezesStart;

$mithelyezat = false;
if ( isset($_GET['mithelyezat']) ) {
	$mithelyezat = (int)$_GET['mithelyezat'];
}

/**
 * Ugyanarra az asztalta nem lehet thelezni
 */ 
if ($asztalkod==$asztalFrom)
{
    header('Location:'.URL.'replace_choose/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod);
	exit();
}

/**
 * Honnan helyeznk t
 */ 
$honnanAsztal = '';
$honnanSQL = "SELECT azonosito, asztalkod FROM dbo.asztalok WHERE asztalKod=".$asztalFrom;
$honnanAsztalQuery = myQuery($honnanSQL);

if (is_array($honnanAsztalQuery) && count($honnanAsztalQuery) > 0)
{
    $honnanAsztal = $honnanAsztalQuery['azonosito'];
}

/**
 * Hova helyeznk t
 */ 
$hovaAsztal = '';
$hovaSQL = "SELECT azonosito, asztalkod FROM dbo.asztalok WHERE asztalKod=".$asztalkod;
$hovaAsztalQuery = myQuery($hovaSQL);

if (is_array($hovaAsztalQuery) && count($hovaAsztalQuery) > 0)
{
    $hovaAsztal = $hovaAsztalQuery['azonosito'];
}

/**
  TTELEK TMSOLSA AZ IDEIGLENES TBLBA
*/ 

if ($athelyezesStart == '1') {
	$attoltes_query = "EXEC [dbo].[insertAthelyezesTemp] ".$jobID.", ".$asztalFrom.", ".$asztalkod.", ".(int)$_SESSION['userID'].";";
	myQuery($attoltes_query);
    $athelyezesStart+=1;	        
} else {
  $athelyezesStart+=1;   
} 

if ($athelyez == '2'){
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 1, 1;";
	myQuery($update_query);
}

if ($athelyez == '4'){
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 1, 0;";
	myQuery($update_query);
}

if ($athelyez == '3') {
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 0, 1;";
	myQuery($update_query) ;
}

if ($athelyez == '5') {
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 0, 0;";
	myQuery($update_query) ;
}

/**
 * thelyezs lezrsa
 */ 
if (isset($_GET['athelyezes_parancs']) && $_GET['athelyezes_parancs']=='1') {
	$user = (int)$_SESSION['userID'];
	$maradek = 0;

	$dbjobitems3 = array();
	$dbjobitems3 = myQuery("SELECT dbo.athelyezesTemp.athelyezesTempId, dbo.EnuProduct.NameShort, dbo.athelyezesTemp.athelyezettMennyiseg, dbo.athelyezesTemp.indok, 
						 i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg AS maradoMenny, dbo.athelyezesTemp.honnan, dbo.athelyezesTemp.hova
						 FROM dbo.athelyezesTemp 
						 JOIN JobOrderItems i on i.jobOrdeItemsID = eredetiTetelKod --to get rid of deleted rows 
						 LEFT OUTER JOIN dbo.EnuProduct ON dbo.athelyezesTemp.termekKod = dbo.EnuProduct.EnuProductID
						 WHERE honnan=".$asztalFrom."
						 AND hova=".$asztalkod." 
						 AND (i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg)>0
						 ORDER BY athelyezesTempId ASC;", null, false);
		   
	//ttelek kilistzsa 
	if (is_array($dbjobitems3) && count($dbjobitems3)>0) {
	  $maradek = count($dbjobitems3);
	}
  
	//Meglv rendels ellenrzse a clasztalon
	$new_jobID = 0;
	$jobcheck = myQuery("SELECT jobOrderID as jobID FROM dbo.JobOrder WHERE ((originalJobOrderID is NULL) OR (originalJobOrderID=0)) AND (MAP_TABLE_1=".$asztalkod.");");
	if (isset($jobcheck) && is_array($jobcheck) && isset($jobcheck['jobID']) && $jobcheck['jobID']>0)
		$new_jobID = $jobcheck['jobID']; 

	if ($new_jobID == 0) {
	  $update_query3 = "EXEC [dbo].[insertRendelesAthelyezes] ".$user.", ".$jobID.", ".$asztalkod.", ".$maradek.";";
	  
	  if (myQuery($update_query3))
	  {
		$jobcheck = myQuery("SELECT MAX(jobOrderID) as jobID FROM dbo.JobOrder;");
		if (isset($jobcheck) && is_array($jobcheck) && $jobcheck['jobID']>0)
		$new_jobID = $jobcheck['jobID'];   
	  }
	}    
	

	if ($new_jobID>0) {
	   $update_query4 = "EXEC [dbo].[updateAthelyezesLezaras] ".$asztalFrom.", ".$asztalkod.", ".$jobID.", ".$new_jobID.", ".$user.";";       
	   
	   if (myQuery($update_query4)) {
		   	$tetelekszama = myQuery("SELECT * FROM dbo.JobOrderItems WHERE JobOrderID='".$jobID."';");
			$reszszamlak = myQuery("SELECT * FROM dbo.JobOrder WHERE originalJobOrderID='".$jobID."';");

			if ((count($tetelekszama) === 0) && (count($reszszamlak ) === 0))
			{
				$torles_allapota = myQuery("DELETE FROM JobOrder WHERE jobOrderID='".$jobID."';");
				myQuery("UPDATE asztalElrendezes SET allapot=40101, rendelesKod=0 WHERE asztalKod=".$asztalFrom);
			}
			$t = myQuery("DELETE FROM dbo.sysjobOrderOpens WHERE JobOrderID=$jobID;");

			header("Location:" . URL .'table/'.$asztalkod);
			exit(); 
	   }
	} 

}
?>

<div id="header_replace" data-role="header">
<!-- tartalom start -->
<?php

$tetelek ='';
$vannaktetelek = false;
	
//ttelek lekrdezse DB-bl
$dbjobitems = array();
$dbjobitems = myQuery("SELECT dbo.athelyezesTemp.athelyezesTempId, dbo.EnuProduct.NameShort, dbo.athelyezesTemp.athelyezettMennyiseg, dbo.athelyezesTemp.indok, 
				 i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg AS maradoMenny, dbo.athelyezesTemp.honnan, dbo.athelyezesTemp.hova,
				 EnuProduct.isWithProduct, i.ConnectedToItemID, i.ConnectedToToolItemID, joi2.jobOrdeItemsID as hasConnectedItem
				 FROM dbo.athelyezesTemp 
				 JOIN dbo.jobOrderItems i ON dbo.athelyezesTemp.eredetiTetelKod = i.jobOrdeItemsID --to get rid of deleted rows
				 LEFT OUTER JOIN dbo.EnuProduct ON dbo.athelyezesTemp.termekKod = dbo.EnuProduct.EnuProductID
				 LEFT OUTER JOIN dbo.jobOrderItems as joi2 ON joi2.jobOrdeItemsID = i.ConnectedToToolItemID
				 WHERE honnan=".$asztalFrom."
				 AND hova=".$asztalkod." 
				 AND (i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg)!=0
				 ORDER BY athelyezesTempId ASC;", null, false);
//ttelek kilistzsa 
if (is_array($dbjobitems) && count($dbjobitems)>0)
{
	$vannaktetelek = true;
	$tetelek = '<table class="tbl_items" cellpadding="0" cellspacing="0" border="0">
				<a name=tetelek>
				<tr class="tbl_items_titles">
					<td><b>#</b></td>
					<td><b>'.lang('NAME').'</b></td>
					<td><b>'.lang('PCS').'</b></td>
					<td><b>'.lang('MOVE').'</b></td>
					<td><b>'.lang('ALL').'</b></td>
				</tr>';
	$x=1;
	
	foreach($dbjobitems as $azonosito=>$p)
	{
		if (floatval($p['maradoMenny'])!=0)
		{                   
			$name = iconv('ISO-8859-1', 'UTF-8', trim($p['NameShort']));
			$numberof = $p['maradoMenny'];
			
			$comment = iconv('ISO-8859-2', 'UTF-8', $p['indok']);	

			$connectedItem = false;
			//if ( !is_null($p['ConnectedToToolItemID']) ) {
			if ( !is_null($p['ConnectedToItemID']) ) {				
				$connectedItem = true;
			}			
											
			$rowtype = ($x%2==1) ? 'even' : 'odd';															
																																												  
			$tetelek .= '<tr class="tbl_items_'.$rowtype.'">
							<td><b>'.$x.'.</b></td>
							<td>'.$name.'</td>
							<td>'.$numberof.'</td>
							'.(($numberof!=0 && !$connectedItem) ? '<td><a class="button red-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=2&mithelyezat='.$p['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('MOVE').'</a></td>': '<td style="text-align:center">-</td>').'</td>  
							'.(($numberof!=0 && !$connectedItem) ? '<td><a class="button blue-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=4&mithelyezat='.$p['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('ALL').'</a></td>': '<td style="text-align:center">-</td>').'</td>
						 </tr>';
			$x++;
		}
	}
	$tetelek .= '</table>';				
}

$tetelek2 ='';
$vannaktetelek2 = false;

//ttelek lekrdezse DB-bl
$dbjobitems2 = array();
$dbjobitems2 = myQuery("SELECT dbo.athelyezesTemp.athelyezesTempId, dbo.EnuProduct.NameShort, dbo.athelyezesTemp.athelyezettMennyiseg, dbo.athelyezesTemp.indok, 
				 i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg AS maradoMenny, dbo.athelyezesTemp.honnan, dbo.athelyezesTemp.hova,
				 EnuProduct.isWithProduct, i.ConnectedToToolItemID, joi2.jobOrdeItemsID as hasConnectedItem
				 FROM dbo.athelyezesTemp 			 
				 JOIN dbo.jobOrderItems i ON dbo.athelyezesTemp.eredetiTetelKod = i.jobOrdeItemsID --to get rid of deleted rows
				 LEFT OUTER JOIN dbo.EnuProduct ON dbo.athelyezesTemp.termekKod = dbo.EnuProduct.EnuProductID	
				 LEFT OUTER JOIN dbo.jobOrderItems as joi2 ON joi2.jobOrdeItemsID = i.ConnectedToToolItemID
				 WHERE honnan=".$asztalFrom."
				 AND hova=".$asztalkod." 
				 AND (athelyezettMennyiseg)!=0
				 ORDER BY athelyezesTempId ASC;", null, false);

//ttelek kilistzsa 
if (is_array($dbjobitems2) && count($dbjobitems2)>0)
{
	$vannaktetelek2 = true;
	$tetelek2 = '<table class="tbl_items" cellpadding="0" cellspacing="0" border="0">
				<a name=tetelek2>
				<tr class="tbl_items_titles">
					<td><b>#</b></td>
					<td><b>'.lang('NAME').'</b></td>
					<td><b>'.lang('PCS').'</b></td>
					<td><b>'.lang('BACK').'</b></td>
					<td><b>'.lang('ALL').'</b></td>
				</tr>';
	$x2=1;
	
	foreach($dbjobitems2 as $azonosito2=>$p2)
	{					
		if (floatval($p2['athelyezettMennyiseg'])!=0)
		{                   
			$name2 = iconv('ISO-8859-1', 'UTF-8', trim($p2['NameShort']));
			$numberof2 = $p2['athelyezettMennyiseg'];
			
			$comment2 = iconv('ISO-8859-2', 'UTF-8', $p2['indok']);
			 
			$connectedItem = false;
			if ( !is_null($p2['ConnectedToToolItemID']) ) {
				$connectedItem = true;
			}			

			$rowtype2 = ($x2%2==1) ? 'even' : 'odd';															
			$tetelek2 .= '<tr class="tbl_items_'.$rowtype2.'">
							<td><b>'.$x2.'.</b></td>
							<td>'.$name2.'</td>
							<td>'.$numberof2.'</td>
							'.(($numberof2!=0 && !$connectedItem) ? '<td><a class="button red-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=3&mithelyezat='.$p2['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('BACK').'</a></td>': '<td style="text-align:center">-</td>').'</td>  
							'.(($numberof2!=0 && !$connectedItem) ? '<td><a class="button blue-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=5&mithelyezat='.$p2['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('ALL').'</a></td>': '<td style="text-align:center">-</td>').'</td>  
						 </tr>';
			$x2++;
		}
	}
	
	$tetelek2 .= '</table>';				
}
	
//eredmny kirsa
		
echo '<div>
		</table>
		<div id="honnan">
			<label>'.lang('MOVE_FROM').': '.$honnanAsztal.'</label>
			<b style="font-size:1.1em"></b>
			'.$tetelek.'  
		</div>
		<div id="hova">
			<label>'.lang('MOVE_TO').': '.$hovaAsztal.'</label>
			<b style="font-size:1.1em"></b>
			'.$tetelek2.'  
		</div>
		
		<div id="bottom">
		<form method="get" action="">
			<input type="hidden" name="athelyezesStart" value="'.$athelyezesStart.'" />
			<input type="hidden" name="athelyezes_parancs" value="1" />
			<input type="submit" class="button red-glossy" width="100" value="'.lang('MOVE').'" id="athelyezes">
		</form>
		<br>
		<a class="button blue-glossy" href="'.URL.'table/'.$asztalFrom .'">'.lang('CANCEL').'</a>
	  </div>';

==> 507_3_2_1_newpda.zip: release/pages/replace_page.php <==
<?php

/**
 * Vltozk definilsa
 */ 
$szel=DOBOZSZELESSEG;
$mag=DOBOZMAGASSAG;
$lap=LAPMERET;
$szerviz=SZERVIZDIJ;
$szervizeng=SZERVIZDIJENG;
$kedv1=KEDV1;
$kedv1eng=KEDV1ENG;
$kedv2=KEDV2;
$kedv2eng=KEDV2ENG;
$kedv3=KEDV3;
$kedv3eng=KEDV3ENG;
$kedv4=KEDV4;
$kedv4eng=KEDV4ENG;
$autoszervizertek=AUTOSZERVIZERTEK;

 
$asztalFrom = (int)$vars[1];
$jobID = (int)$vars[2];
$asztalkod = (int)$vars[3];

$station = 1;

$athelyez = (isset($_GET['athelyez'])) ? (int)$_GET['athelyez'] : 0;
$athelyez = ($athelyez==0) ? 1 : $athelyez;

$athelyezesStart = (isset($_GET['athelyezesStart'])) ? (int)$_GET['athelyezesStart'] : 0;
$athelyezesStart = ($athelyezesStart==0) ? 1 : $athelyezesStart;

$mithelyezat = false;
if ( isset($_GET['mithelyezat']) ) {
	$mithelyezat = (int)$_GET['mithelyezat'];
}

/**
 * Ugyanarra az asztalta nem lehet thelezni
 */ 
if ($asztalkod==$asztalFrom)
{
    header('Location:'.URL.'replace_choose/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod);
	exit();
}

/**
 * Honnan helyeznk t
 */ 
$honnanAsztal = '';
$honnanSQL = "SELECT azonosito, asztalkod FROM dbo.asztalok WHERE asztalKod=".$asztalFrom;
$honnanAsztalQuery = myQuery($honnanSQL);

if (is_array($honnanAsztalQuery) && count($honnanAsztalQuery) > 0)
{
    $honnanAsztal = $honnanAsztalQuery['azonosito'];
}

/**
 * Hova helyeznk t
 */ 
$hovaAsztal = '';
$hovaSQL = "SELECT azonosito, asztalkod FROM dbo.asztalok WHERE asztalKod=".$asztalkod;
$hovaAsztalQuery = myQuery($hovaSQL);

if (is_array($hovaAsztalQuery) && count($hovaAsztalQuery) > 0)
{
    $hovaAsztal = $hovaAsztalQuery['azonosito'];
}

/**
  TTELEK TMSOLSA AZ IDEIGLENES TBLBA
*/ 

if ($athelyezesStart == '1') {
	$attoltes_query = "EXEC [dbo].[insertAthelyezesTemp] ".$jobID.", ".$asztalFrom.", ".$asztalkod.", ".(int)$_SESSION['userID'].";";
	myQuery($attoltes_query);
    $athelyezesStart+=1;	        
} else {
  $athelyezesStart+=1;   
} 

if ($athelyez == '2'){
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 1, 1;";
	myQuery($update_query);
}

if ($athelyez == '4'){
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 1, 0;";
	myQuery($update_query);
}

if ($athelyez == '3') {
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 0, 1;";
	myQuery($update_query) ;
}

if ($athelyez == '5') {
	$update_query = "EXEC [dbo].[updateAthelyezesTemp] ".$mithelyezat.", 0, 0;";
	myQuery($update_query) ;
}

/**
 * thelyezs lezrsa
 */ 
if (isset($_GET['athelyezes_parancs']) && $_GET['athelyezes_parancs']=='1') {
	$user = (int)$_SESSION['userID'];
	$maradek = 0;

	$dbjobitems3 = array();
	$dbjobitems3 = myQuery("SELECT dbo.athelyezesTemp.athelyezesTempId, dbo.EnuProduct.NameShort, dbo.athelyezesTemp.athelyezettMennyiseg, dbo.athelyezesTemp.indok, 
						 i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg AS maradoMenny, dbo.athelyezesTemp.honnan, dbo.athelyezesTemp.hova
						 FROM dbo.athelyezesTemp 
						 JOIN JobOrderItems i on i.jobOrdeItemsID = eredetiTetelKod --to get rid of deleted rows 
						 LEFT OUTER JOIN dbo.EnuProduct ON dbo.athelyezesTemp.termekKod = dbo.EnuProduct.EnuProductID
						 WHERE honnan=".$asztalFrom."
						 AND hova=".$asztalkod." 
						 AND (i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg)>0
						 ORDER BY athelyezesTempId ASC;", null, false);
		   
	//ttelek kilistzsa 
	if (is_array($dbjobitems3) && count($dbjobitems3)>0) {
	  $maradek = count($dbjobitems3);
	}
  
	//Meglv rendels ellenrzse a clasztalon
	$new_jobID = 0;
	$jobcheck = myQuery("SELECT jobOrderID as jobID FROM dbo.JobOrder WHERE ((originalJobOrderID is NULL) OR (originalJobOrderID=0)) AND (MAP_TABLE_1=".$asztalkod.");");
	if (isset($jobcheck) && is_array($jobcheck) && isset($jobcheck['jobID']) && $jobcheck['jobID']>0)
		$new_jobID = $jobcheck['jobID']; 

	if ($new_jobID == 0) {
	  $update_query3 = "EXEC [dbo].[insertRendelesAthelyezes] ".$user.", ".$jobID.", ".$asztalkod.", ".$maradek.";";
	  
	  if (myQuery($update_query3))
	  {
		$jobcheck = myQuery("SELECT MAX(jobOrderID) as jobID FROM dbo.JobOrder;");
		if (isset($jobcheck) && is_array($jobcheck) && $jobcheck['jobID']>0)
		$new_jobID = $jobcheck['jobID'];   
	  }
	}    
	

	if ($new_jobID>0) {
	   $update_query4 = "EXEC [dbo].[updateAthelyezesLezaras] ".$asztalFrom.", ".$asztalkod.", ".$jobID.", ".$new_jobID.", ".$user.";";       
	   
	   if (myQuery($update_query4)) {
		   	$tetelekszama = myQuery("SELECT * FROM dbo.JobOrderItems WHERE JobOrderID='".$jobID."';");
			$reszszamlak = myQuery("SELECT * FROM dbo.JobOrder WHERE originalJobOrderID='".$jobID."';");

			if ((count($tetelekszama) === 0) && (count($reszszamlak ) === 0))
			{
				$torles_allapota = myQuery("DELETE FROM JobOrder WHERE jobOrderID='".$jobID."';");
				myQuery("UPDATE asztalElrendezes SET allapot=40101, rendelesKod=0 WHERE asztalKod=".$asztalFrom);
			}
			$t = myQuery("DELETE FROM dbo.sysjobOrderOpens WHERE JobOrderID=$jobID;");

			header("Location:" . URL .'table/'.$asztalkod);
			exit(); 
	   }
	} 

}
?>

<div id="header_replace" data-role="header">
<!-- tartalom start -->
<?php

$tetelek ='';
$vannaktetelek = false;
	
//ttelek lekrdezse DB-bl
$dbjobitems = array();
$dbjobitems = myQuery("SELECT dbo.athelyezesTemp.athelyezesTempId, dbo.EnuProduct.NameShort, dbo.athelyezesTemp.athelyezettMennyiseg, dbo.athelyezesTemp.indok, 
				 i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg AS maradoMenny, dbo.athelyezesTemp.honnan, dbo.athelyezesTemp.hova,
				 EnuProduct.isWithProduct, i.ConnectedToItemID, i.ConnectedToToolItemID, joi2.jobOrdeItemsID as hasConnectedItem
				 FROM dbo.athelyezesTemp 
				 JOIN dbo.jobOrderItems i ON dbo.athelyezesTemp.eredetiTetelKod = i.jobOrdeItemsID --to get rid of deleted rows
				 LEFT OUTER JOIN dbo.EnuProduct ON dbo.athelyezesTemp.termekKod = dbo.EnuProduct.EnuProductID
				 LEFT OUTER JOIN dbo.jobOrderItems as joi2 ON joi2.jobOrdeItemsID = i.ConnectedToToolItemID
				 WHERE honnan=".$asztalFrom."
				 AND hova=".$asztalkod." 
				 AND (i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg)!=0
				 ORDER BY athelyezesTempId ASC;", null, false);
//ttelek kilistzsa 
if (is_array($dbjobitems) && count($dbjobitems)>0)
{
	$vannaktetelek = true;
	$tetelek = '<table class="tbl_items" cellpadding="0" cellspacing="0" border="0">
				<a name=tetelek>
				<tr class="tbl_items_titles">
					<td><b>#</b></td>
					<td><b>'.lang('NAME').'</b></td>
					<td><b>'.lang('PCS').'</b></td>
					<td><b>'.lang('MOVE').'</b></td>
					<td><b>'.lang('ALL').'</b></td>
				</tr>';
	$x=1;
	
	foreach($dbjobitems as $azonosito=>$p)
	{
		if (floatval($p['maradoMenny'])!=0)
		{                   
			$name = iconv('ISO-8859-1', 'UTF-8', trim($p['NameShort']));
			$numberof = $p['maradoMenny'];
			
			$comment = iconv('ISO-8859-2', 'UTF-8', $p['indok']);	

			$connectedItem = false;
			//if ( !is_null($p['ConnectedToToolItemID']) ) {
			if ( !is_null($p['ConnectedToItemID']) ) {				
				$connectedItem = true;
			}			
											
			$rowtype = ($x%2==1) ? 'even' : 'odd';															
																																												  
			$tetelek .= '<tr class="tbl_items_'.$rowtype.'">
							<td><b>'.$x.'.</b></td>
							<td>'.$name.'</td>
							<td>'.$numberof.'</td>
							'.(($numberof!=0 && !$connectedItem) ? '<td><a class="button red-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=2&mithelyezat='.$p['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('MOVE').'</a></td>': '<td style="text-align:center">-</td>').'</td>  
							'.(($numberof!=0 && !$connectedItem) ? '<td><a class="button blue-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=4&mithelyezat='.$p['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('ALL').'</a></td>': '<td style="text-align:center">-</td>').'</td>
						 </tr>';
			$x++;
		}
	}
	$tetelek .= '</table>';				
}

$tetelek2 ='';
$vannaktetelek2 = false;

//ttelek lekrdezse DB-bl
$dbjobitems2 = array();
$dbjobitems2 = myQuery("SELECT dbo.athelyezesTemp.athelyezesTempId, dbo.EnuProduct.NameShort, dbo.athelyezesTemp.athelyezettMennyiseg, dbo.athelyezesTemp.indok, 
				 i.Quantity - dbo.athelyezesTemp.athelyezettMennyiseg AS maradoMenny, dbo.athelyezesTemp.honnan, dbo.athelyezesTemp.hova,
				 EnuProduct.isWithProduct, i.ConnectedToToolItemID, joi2.jobOrdeItemsID as hasConnectedItem
				 FROM dbo.athelyezesTemp 			 
				 JOIN dbo.jobOrderItems i ON dbo.athelyezesTemp.eredetiTetelKod = i.jobOrdeItemsID --to get rid of deleted rows
				 LEFT OUTER JOIN dbo.EnuProduct ON dbo.athelyezesTemp.termekKod = dbo.EnuProduct.EnuProductID	
				 LEFT OUTER JOIN dbo.jobOrderItems as joi2 ON joi2.jobOrdeItemsID = i.ConnectedToToolItemID
				 WHERE honnan=".$asztalFrom."
				 AND hova=".$asztalkod." 
				 AND (athelyezettMennyiseg)!=0
				 ORDER BY athelyezesTempId ASC;", null, false);

//ttelek kilistzsa 
if (is_array($dbjobitems2) && count($dbjobitems2)>0)
{
	$vannaktetelek2 = true;
	$tetelek2 = '<table class="tbl_items" cellpadding="0" cellspacing="0" border="0">
				<a name=tetelek2>
				<tr class="tbl_items_titles">
					<td><b>#</b></td>
					<td><b>'.lang('NAME').'</b></td>
					<td><b>'.lang('PCS').'</b></td>
					<td><b>'.lang('BACK').'</b></td>
					<td><b>'.lang('ALL').'</b></td>
				</tr>';
	$x2=1;
	
	foreach($dbjobitems2 as $azonosito2=>$p2)
	{					
		if (floatval($p2['athelyezettMennyiseg'])!=0)
		{                   
			$name2 = iconv('ISO-8859-1', 'UTF-8', trim($p2['NameShort']));
			$numberof2 = $p2['athelyezettMennyiseg'];
			
			$comment2 = iconv('ISO-8859-2', 'UTF-8', $p2['indok']);
			 
			$connectedItem = false;
			if ( !is_null($p2['ConnectedToToolItemID']) ) {
				$connectedItem = true;
			}			

			$rowtype2 = ($x2%2==1) ? 'even' : 'odd';															
			$tetelek2 .= '<tr class="tbl_items_'.$rowtype2.'">
							<td><b>'.$x2.'.</b></td>
							<td>'.$name2.'</td>
							<td>'.$numberof2.'</td>
							'.(($numberof2!=0 && !$connectedItem) ? '<td><a class="button red-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=3&mithelyezat='.$p2['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('BACK').'</a></td>': '<td style="text-align:center">-</td>').'</td>  
							'.(($numberof2!=0 && !$connectedItem) ? '<td><a class="button blue-glossy" href="'. URL .'replace/'.$asztalFrom.'/'.$jobID.'/'.$asztalkod.'?athelyez=5&mithelyezat='.$p2['athelyezesTempId'].'&athelyezesStart='.$athelyezesStart.'#tetelek'.'">'.lang('ALL').'</a></td>': '<td style="text-align:center">-</td>').'</td>  
						 </tr>';
			$x2++;
		}
	}
	
	$tetelek2 .= '</table>';				
}
	
//eredmny kirsa
		
echo '<div>
		</table>
		<div id="honnan">
			<label>'.lang('MOVE_FROM').': '.$honnanAsztal.'</label>
			<b style="font-size:1.1em"></b>
			'.$tetelek.'  
		</div>
		<div id="hova">
			<label>'.lang('MOVE_TO').': '.$hovaAsztal.'</label>
			<b style="font-size:1.1em"></b>
			'.$tetelek2.'  
		</div>
		
		<div id="bottom">
		<form method="get" action="">
			<input type="hidden" name="athelyezesStart" value="'.$athelyezesStart.'" />
			<input type="hidden" name="athelyezes_parancs" value="1" />
			<input type="submit" class="button red-glossy" width="100" value="'.lang('MOVE').'" id="athelyezes">
		</form>
		<br>
		<a class="button blue-glossy" href="'.URL.'table/'.$asztalFrom .'">'.lang('CANCEL').'</a>
	  </div>';
